@@ -36,7 +36,7 @@ warnings.warn("Bio.DocSQL is now deprecated will be removed in a "
 
 try:
     import MySQLdb
-except:
+except ImportError:
     raise MissingPythonDependencyError("Install MySQLdb if you want to use "
                                        "Bio.DocSQL.")
 
@@ -90,9 +90,8 @@ class QueryRow(list):
 
 
 class Query(object):
-    """
-    SHOW TABLES
-    """
+    """SHOW TABLES."""
+
     MSG_FAILURE = "Failure"
     MSG_SUCCESS = "Success"
     message = "not executed"
@@ -227,6 +226,7 @@ def _test(*args, **keywds):
     import doctest
     doctest.testmod(sys.modules[__name__], *args, **keywds)
 
+
 if __name__ == "__main__":
     if __debug__:
         _test()
