@@ -53,22 +53,22 @@ class _ChromosomeComponent(Widget):
     This class should not be instantiated directly, but should be used
     from derived classes.
     """
+
     def __init__(self):
         """Initialize a chromosome component.
 
         Attributes:
-
-        o _sub_components -- Any components which are contained under
+        - _sub_components -- Any components which are contained under
         this parent component. This attribute should be accessed through
         the add() and remove() functions.
+
         """
         self._sub_components = []
 
     def add(self, component):
-        """Add a sub_component to the list of components under this item.
-        """
+        """Add a sub_component to the list of components under this item."""
         assert isinstance(component, _ChromosomeComponent), \
-               "Expected a _ChromosomeComponent object, got %s" % component
+            "Expected a _ChromosomeComponent object, got %s" % component
 
         self._sub_components.append(component)
 
@@ -85,8 +85,7 @@ class _ChromosomeComponent(Widget):
                              component)
 
     def draw(self):
-        """Draw the specified component.
-        """
+        """Draw the specified component."""
         raise AssertionError("Subclasses must implement.")
 
 
@@ -100,7 +99,9 @@ class Organism(_ChromosomeComponent):
     Chromosomes should be added and removed from the Organism via the
     add and remove functions.
     """
+
     def __init__(self, output_format='pdf'):
+        """Initialize."""
         _ChromosomeComponent.__init__(self)
 
         # customizable attributes
@@ -117,15 +118,14 @@ class Organism(_ChromosomeComponent):
         """Draw out the information for the Organism.
 
         Arguments:
+         - output_file -- The name of a file specifying where the
+           document should be saved, or a handle to be written to.
+           The output format is set when creating the Organism object.
+           Alternatively, output_file=None will return the drawing using
+           the low-level ReportLab objects (for further processing, such
+           as adding additional graphics, before writing).
+         - title -- The output title of the produced document.
 
-        o output_file -- The name of a file specifying where the
-        document should be saved, or a handle to be written to.
-        The output format is set when creating the Organism object.
-        Alternatively, output_file=None will return the drawing using
-        the low-level ReportLab objects (for further processing, such
-        as adding additional graphics, before writing).
-
-        o title -- The output title of the produced document.
         """
         width, height = self.page_size
         cur_drawing = Drawing(width, height)
@@ -161,8 +161,7 @@ class Organism(_ChromosomeComponent):
         return _write(cur_drawing, output_file, self.output_format)
 
     def _draw_title(self, cur_drawing, title, width, height):
-        """Write out the title of the organism figure.
-        """
+        """Write out the title of the organism figure."""
         title_string = String(width / 2, height - inch, title)
         title_string.fontName = 'Helvetica-Bold'
         title_string.fontSize = self.title_size
@@ -186,31 +185,28 @@ class Chromosome(_ChromosomeComponent):
     class can be instantiated directly, but the draw method makes the
     most sense to be called in the context of an organism.
     """
+
     def __init__(self, chromosome_name):
         """Initialize a Chromosome for drawing.
 
         Arguments:
-
-        o chromosome_name - The label for the chromosome.
+         - chromosome_name - The label for the chromosome.
 
         Attributes:
-
-        o start_x_position, end_x_position - The x positions on the page
-        where the chromosome should be drawn. This allows multiple
-        chromosomes to be drawn on a single page.
-
-        o start_y_position, end_y_position - The y positions on the page
-        where the chromosome should be contained.
+         - start_x_position, end_x_position - The x positions on the page
+           where the chromosome should be drawn. This allows multiple
+           chromosomes to be drawn on a single page.
+         - start_y_position, end_y_position - The y positions on the page
+           where the chromosome should be contained.
 
         Configuration Attributes:
+         - title_size - The size of the chromosome title.
+         - scale_num - A number of scale the drawing by. This is useful if
+           you want to draw multiple chromosomes of different sizes at the
+           same scale. If this is not set, then the chromosome drawing will
+           be scaled by the number of segements in the chromosome (so each
+           chromosome will be the exact same final size).
 
-        o title_size - The size of the chromosome title.
-
-        o scale_num - A number of scale the drawing by. This is useful if
-        you want to draw multiple chromosomes of different sizes at the
-        same scale. If this is not set, then the chromosome drawing will
-        be scaled by the number of segements in the chromosome (so each
-        chromosome will be the exact same final size).
         """
         _ChromosomeComponent.__init__(self)
 
@@ -230,8 +226,7 @@ class Chromosome(_ChromosomeComponent):
         self._color_labels = False
 
     def subcomponent_size(self):
-        """Return the scaled size of all subcomponents of this component.
-        """
+        """Return the scaled size of all subcomponents of this component."""
         total_sub = 0
         for sub_component in self._sub_components:
             total_sub += sub_component.scale
@@ -286,8 +281,7 @@ class Chromosome(_ChromosomeComponent):
         self._draw_label(cur_drawing, self._name)
 
     def _draw_label(self, cur_drawing, label_name):
-        """Draw a label for the chromosome.
-        """
+        """Draw a label for the chromosome."""
         x_position = 0.5 * (self.start_x_position + self.end_x_position)
         y_position = self.end_y_position
 
@@ -313,15 +307,16 @@ class Chromosome(_ChromosomeComponent):
         color_label = self._color_labels
 
         segment_width = (self.end_x_position - self.start_x_position) \
-                        * self.chr_percent
+            * self.chr_percent
         label_sep = (self.end_x_position - self.start_x_position) \
-                        * self.label_sep_percent
+            * self.label_sep_percent
         segment_x = self.start_x_position \
-                  + 0.5 * (self.end_x_position - self.start_x_position - segment_width)
+            + 0.5 * (self.end_x_position - self.start_x_position - segment_width)
 
         y_limits = []
         for sub_component in self._sub_components:
-            y_limits.extend((sub_component.start_y_position, sub_component.end_y_position))
+            y_limits.extend((sub_component.start_y_position,
+                             sub_component.end_y_position))
         y_min = min(y_limits)
         y_max = max(y_limits)
         del y_limits
@@ -339,7 +334,7 @@ class Chromosome(_ChromosomeComponent):
                  segment_x + segment_width + label_sep,
                  _place_labels(right_labels, y_min, y_max, h),
                  "start"),
-            ]:
+                ]:
             for (y1, y2, color, back_color, name) in labels:
                 cur_drawing.add(Line(x1, y1, x2, y2,
                                      strokeColor=color,
@@ -351,7 +346,9 @@ class Chromosome(_ChromosomeComponent):
                 if color_label:
                     label_string.fillColor = color
                 if back_color:
-                    w = stringWidth(name, label_string.fontName, label_string.fontSize)
+                    w = stringWidth(name,
+                                    label_string.fontName,
+                                    label_string.fontSize)
                     if x1 > x2:
                         w = w * -1.0
                     cur_drawing.add(Rect(x2, y2 - 0.1 * h, w, h,
@@ -368,32 +365,28 @@ class ChromosomeSegment(_ChromosomeComponent):
     be subclassed to define additional functionality. Most of the interesting
     drawing stuff is likely to happen at the ChromosomeSegment level.
     """
+
     def __init__(self):
         """Initialize a ChromosomeSegment.
 
         Attributes:
-        o start_x_position, end_x_position - Defines the x range we have
-        to draw things in.
-
-        o start_y_position, end_y_position - Defines the y range we have
-        to draw things in.
+         - start_x_position, end_x_position - Defines the x range we have
+           to draw things in.
+         - start_y_position, end_y_position - Defines the y range we have
+           to draw things in.
 
         Configuration Attributes:
+         - scale - A scaling value for the component. By default this is
+           set at 1 (ie -- has the same scale as everything else). Higher
+           values give more size to the component, smaller values give less.
+         - fill_color - A color to fill in the segment with. Colors are
+           available in reportlab.lib.colors
+         - label - A label to place on the chromosome segment. This should
+           be a text string specifying what is to be included in the label.
+         - label_size - The size of the label.
+         - chr_percent - The percentage of area that the chromosome
+           segment takes up.
 
-        o scale - A scaling value for the component. By default this is
-        set at 1 (ie -- has the same scale as everything else). Higher
-        values give more size to the component, smaller values give less.
-
-        o fill_color - A color to fill in the segment with. Colors are
-        available in reportlab.lib.colors
-
-        o label - A label to place on the chromosome segment. This should
-        be a text string specifying what is to be included in the label.
-
-        o label_size - The size of the label.
-
-        o chr_percent - The percentage of area that the chromosome
-        segment takes up.
         """
         _ChromosomeComponent.__init__(self)
 
@@ -432,16 +425,15 @@ class ChromosomeSegment(_ChromosomeComponent):
         pass
 
     def _draw_segment(self, cur_drawing):
-        """Draw the current chromosome segment.
-        """
+        """Draw the current chromosome segment."""
         # set the coordinates of the segment -- it'll take up the MIDDLE part
         # of the space we have.
         segment_y = self.end_y_position
         segment_width = (self.end_x_position - self.start_x_position) \
-                        * self.chr_percent
+            * self.chr_percent
         segment_height = self.start_y_position - self.end_y_position
         segment_x = self.start_x_position \
-                  + 0.5 * (self.end_x_position - self.start_x_position - segment_width)
+            + 0.5 * (self.end_x_position - self.start_x_position - segment_width)
 
         # first draw the sides of the segment
         right_line = Line(segment_x, segment_y,
@@ -492,7 +484,7 @@ class ChromosomeSegment(_ChromosomeComponent):
 
 
 def _spring_layout(desired, minimum, maximum, gap=0):
-    """Function to try and layout label co-ordinates (or other floats, PRIVATE).
+    """Try to layout label co-ordinates (or other floats, PRIVATE).
 
     Originally written for the y-axis vertical positioning of labels on a
     chromosome diagram (where the minimum gap between y-axis co-ordinates is
@@ -538,7 +530,11 @@ def _spring_layout(desired, minimum, maximum, gap=0):
         return desired
 
     span = maximum - minimum
-    for split in [0.5 * span, span / 3.0, 2 * span / 3.0, 0.25 * span, 0.75 * span]:
+    for split in [0.5 * span,
+                  span / 3.0,
+                  2 * span / 3.0,
+                  0.25 * span,
+                  0.75 * span]:
         midpoint = minimum + split
         low = [x for x in desired if x <= midpoint - 0.5 * gap]
         high = [x for x in desired if x > midpoint + 0.5 * gap]
@@ -551,8 +547,8 @@ def _spring_layout(desired, minimum, maximum, gap=0):
         elif not high and len(low) * gap <= split + 0.5 * gap:
             # Give a little of the unused highspace to the low points
             return _spring_layout(low, minimum, midpoint - 0.5 * gap, gap)
-        elif len(low) * gap <= split - 0.5 * gap \
-        and len(high) * gap <= (span - split) - 0.5 * gap:
+        elif (len(low) * gap <= split - 0.5 * gap and
+              len(high) * gap <= (span - split) - 0.5 * gap):
             return _spring_layout(low, minimum, midpoint - 0.5 * gap, gap) + \
                    _spring_layout(high, midpoint + 0.5 * gap, maximum, gap)
 
@@ -578,8 +574,11 @@ def _spring_layout(desired, minimum, maximum, gap=0):
     return [minimum + i * equal_step for i in range(count)]
 
 # assert False, _spring_layout([0.10,0.12,0.13,0.14,0.5,0.75, 1.0], 0, 1, 0.1)
-# assert _spring_layout([0.10,0.12,0.13,0.14,0.5,0.75, 1.0], 0, 1, 0.1) == [0.0, 0.125, 0.25, 0.375, 0.5, 0.75, 1.0]
-# assert _spring_layout([0.10,0.12,0.13,0.14,0.5,0.75, 1.0], 0, 1, 0.1) == [0.0, 0.16666666666666666, 0.33333333333333331, 0.5, 0.66666666666666663, 0.83333333333333326, 1.0]
+# assert _spring_layout([0.10,0.12,0.13,0.14,0.5,0.75, 1.0], 0, 1, 0.1) == \
+#     [0.0, 0.125, 0.25, 0.375, 0.5, 0.75, 1.0]
+# assert _spring_layout([0.10,0.12,0.13,0.14,0.5,0.75, 1.0], 0, 1, 0.1) == \
+#     [0.0, 0.16666666666666666, 0.33333333333333331, 0.5,
+#      0.66666666666666663, 0.83333333333333326, 1.0]
 
 
 def _place_labels(desired_etc, minimum, maximum, gap=0):
@@ -593,10 +592,15 @@ def _place_labels(desired_etc, minimum, maximum, gap=0):
 
 
 class AnnotatedChromosomeSegment(ChromosomeSegment):
+    """Annotated chromosome segment.
+
+    This is like the ChromosomeSegment, but accepts a list of features.
+    """
+
     def __init__(self, bp_length, features,
                  default_feature_color=colors.blue,
                  name_qualifiers=('gene', 'label', 'name', 'locus_tag', 'product')):
-        """Like the ChromosomeSegment, but accepts a list of features.
+        """Initialize.
 
         The features can either be SeqFeature objects, or tuples of values:
         start (int), end (int), strand (+1, -1, O or None), label (string),
@@ -640,12 +644,12 @@ class AnnotatedChromosomeSegment(ChromosomeSegment):
         # of the space we have.
         segment_y = self.end_y_position
         segment_width = (self.end_x_position - self.start_x_position) \
-                        * self.chr_percent
+            * self.chr_percent
         label_sep = (self.end_x_position - self.start_x_position) \
-                        * self.label_sep_percent
+            * self.label_sep_percent
         segment_height = self.start_y_position - self.end_y_position
         segment_x = self.start_x_position \
-                  + 0.5 * (self.end_x_position - self.start_x_position - segment_width)
+            + 0.5 * (self.end_x_position - self.start_x_position - segment_width)
 
         left_labels = []
         right_labels = []
@@ -688,8 +692,10 @@ class AnnotatedChromosomeSegment(ChromosomeSegment):
                 x = segment_x
                 w = segment_width
             local_scale = segment_height / self.bp_length
-            fill_rectangle = Rect(x, segment_y + segment_height - local_scale * start,
-                                  w, local_scale * (start - end))
+            fill_rectangle = Rect(x,
+                                  segment_y + segment_height - local_scale * start,
+                                  w,
+                                  local_scale * (start - end))
             fill_rectangle.fillColor = fill_color
             fill_rectangle.strokeColor = color
             cur_drawing.add(fill_rectangle)
@@ -698,7 +704,8 @@ class AnnotatedChromosomeSegment(ChromosomeSegment):
                     back_color = None
                 else:
                     back_color = fill_color
-                value = (segment_y + segment_height - local_scale * start, color, back_color, name)
+                value = (segment_y + segment_height - local_scale * start,
+                         color, back_color, name)
                 if strand == -1:
                     self._left_labels.append(value)
                 else:
@@ -713,6 +720,7 @@ class TelomereSegment(ChromosomeSegment):
     _draw_segment class of ChromosomeSegment to provide that specialized
     drawing.
     """
+
     def __init__(self, inverted=0):
         """Initialize a segment at the end of a chromosome.
 
@@ -720,21 +728,20 @@ class TelomereSegment(ChromosomeSegment):
         customized in a TelomereSegments.
 
         Arguments:
+         - inverted -- Whether or not the telomere should be inverted
+           (ie. drawn on the bottom of a chromosome)
 
-        o inverted -- Whether or not the telomere should be inverted
-        (ie. drawn on the bottom of a chromosome)
         """
         ChromosomeSegment.__init__(self)
 
         self._inverted = inverted
 
     def _draw_segment(self, cur_drawing):
-        """Draw a half circle representing the end of a linear chromosome.
-        """
+        """Draw a half circle representing the end of a linear chromosome."""
         # set the coordinates of the segment -- it'll take up the MIDDLE part
         # of the space we have.
         width = (self.end_x_position - self.start_x_position) \
-                * self.chr_percent
+            * self.chr_percent
         height = self.start_y_position - self.end_y_position
         center_x = 0.5 * (self.end_x_position + self.start_x_position)
         start_x = center_x - 0.5 * width
@@ -769,4 +776,10 @@ class SpacerSegment(ChromosomeSegment):
     """
 
     def draw(self, cur_diagram):
+        """Draw nothing to the current diagram (dummy method).
+
+        The segment spacer has no actual image in the diagram,
+        so this method therefore does nothing, but is defined
+        to match the expected API of the other segment objects.
+        """
         pass
