@@ -3,22 +3,21 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-"""This module provides classes to represent a KGML Pathway Map.
+"""Classes to represent a KGML Pathway Map.
 
 The KGML definition is as of release KGML v0.7.1
 (http://www.kegg.jp/kegg/xml/docs/)
 
 Classes:
+ - Pathway - Specifies graph information for the pathway map
+ - Relation - Specifies a relationship between two proteins or KOs,
+   or protein and compound. There is an implied direction to the
+   relationship in some cases.
+ - Reaction - A specific chemical reaction between a substrate and
+   a product.
+ - Entry - A node in the pathway graph
+ - Graphics - Entry subelement describing its visual representation
 
-    - Pathway              Specifies graph information for the pathway map
-    - Relation             Specifies a relationship between two proteins or
-                           KOs, or protein and compound. There is an implied
-                           direction to the relationship in some cases.
-    - Reaction             A specific chemical reaction between a substrate
-                           and a product.
-    - Entry                A node in the pathway graph
-    - Graphics             Entry subelement describing its visual
-                           representation
 """
 
 import time
@@ -28,8 +27,6 @@ import xml.etree.ElementTree as ET
 
 from Bio._py3k import _is_int_or_long, _as_string
 
-__docformat__ = "restructuredtext en"
-
 
 # Pathway
 class Pathway(object):
@@ -39,14 +36,14 @@ class Pathway(object):
     release KGML v0.7.1 (http://www.kegg.jp/kegg/xml/docs/)
 
     Attributes:
-    name         KEGGID of the pathway map
-    org          ko/ec/[org prefix]
-    number       map number (integer)
-    title        the map title
-    image        URL of the image map for the pathway
-    link         URL of information about the pathway
-    entries      Dictionary of entries in the pathway, keyed by node ID
-    reactions    Set of reactions in the pathway
+     - name - KEGGID of the pathway map
+     - org - ko/ec/[org prefix]
+     - number - map number (integer)
+     - title - the map title
+     - image - URL of the image map for the pathway
+     - link - URL of information about the pathway
+     - entries - Dictionary of entries in the pathway, keyed by node ID
+     - reactions - Set of reactions in the pathway
 
     The name attribute has a restricted format, so we make it a property and
     enforce the formatting.
@@ -62,7 +59,9 @@ class Pathway(object):
     Reactions are held in a dictionary, keyed by node ID for the path.
     The elements referred to in the reaction must be added before the
     reaction itself.
+
     """
+
     def __init__(self):
         self._name = ''
         self.org = ''
@@ -202,9 +201,7 @@ class Pathway(object):
 
     @property
     def reaction_entries(self):
-        """Get a list of entries corresponding to each reaction
-           in the pathway.
-        """
+        """List of entries corresponding to each reaction in the pathway."""
         return [self.entries[i] for i in self._reactions]
 
     @property
@@ -257,20 +254,22 @@ class Entry(object):
     release KGML v0.7.1 (http://www.kegg.jp/kegg/xml/docs/)
 
     Attributes:
-        - id           The ID of the entry in the pathway map (integer)
-        - names        List of KEGG IDs for the entry
-        - type         The type of the entry
-        - link         URL of information about the entry
-        - reaction     List of KEGG IDs of the corresponding reactions
-                       (integer)
-        - graphics     List of Graphics objects describing the Entry's visual
-                       representation
-        - components   List of component node ID for this Entry ('group')
-        - alt          List of alternate names for the Entry
+     - id - The ID of the entry in the pathway map (integer)
+     - names - List of KEGG IDs for the entry
+     - type - The type of the entry
+     - link - URL of information about the entry
+     - reaction - List of KEGG IDs of the corresponding reactions
+       (integer)
+     - graphics -    List of Graphics objects describing the Entry's visual
+       representation
+     - components - List of component node ID for this Entry ('group')
+     - alt - List of alternate names for the Entry
 
     NOTE: The alt attribute represents a subelement of the substrate and
     product elements in the KGML file
+
     """
+
     def __init__(self):
         self._id = None
         self._names = []
@@ -411,6 +410,7 @@ class Component(object):
     The Component acts as a collection (with type 'group', and typically
     its own Graphics subelement), having only an ID.
     """
+
     def __init__(self, parent):
         self._id = None
         self._parent = parent
@@ -445,22 +445,24 @@ class Graphics(object):
     described in release KGML v0.7.1 (http://www.kegg.jp/kegg/xml/docs/)
 
     Attributes:
-    name         Label for the graphics object
-    x            X-axis position of the object (int)
-    y            Y-axis position of the object (int)
-    coords       polyline co-ordinates, list of (int, int) tuples
-    type         object shape
-    width        object width (int)
-    height       object height (int)
-    fgcolor      object foreground color (hex RGB)
-    bgcolor      object background color (hex RGB)
+     - name         Label for the graphics object
+     - x            X-axis position of the object (int)
+     - y            Y-axis position of the object (int)
+     - coords       polyline co-ordinates, list of (int, int) tuples
+     - type         object shape
+     - width        object width (int)
+     - height       object height (int)
+     - fgcolor      object foreground color (hex RGB)
+     - bgcolor      object background color (hex RGB)
 
     Some attributes are present only for specific graphics types.  For
     example, line types do not (typically) have a width.
     We permit non-DTD attributes and attribute settings, such as
 
     dash         List of ints, describing an on/off pattern for dashes
+
     """
+
     def __init__(self, parent):
         self.name = ''
         self._x = None
@@ -619,12 +621,14 @@ class Reaction(object):
     substrates and one or more products.
 
     Attributes:
-    id             Pathway graph node ID of the entry
-    names          List of KEGG identifier(s) from the REACTION database
-    type           String: reversible or irreversible
-    substrate      Entry object of the substrate
-    product        Entry object of the product
+     - id             Pathway graph node ID of the entry
+     - names          List of KEGG identifier(s) from the REACTION database
+     - type           String: reversible or irreversible
+     - substrate      Entry object of the substrate
+     - product        Entry object of the product
+
     """
+
     def __init__(self):
         self._id = None
         self._names = []
@@ -708,11 +712,6 @@ class Reaction(object):
         """Return a list of substrate and product reactant IDs."""
         return self._products.union(self._substrates)
 
-    @property
-    def entry(self):
-        """Return the Entry corresponding to this reaction."""
-        return self._pathway.entries[self._id]
-
     @property
     def element(self):
         """Return KGML element describing the Reaction."""
@@ -743,15 +742,16 @@ class Relation(object):
     (http://www.kegg.jp/kegg/xml/docs/)
 
     Attributes:
+     - entry1 - The first Entry object node ID defining the
+       relation (int)
+     - entry2 - The second Entry object node ID defining the
+       relation (int)
+     - type - The relation type
+     - subtypes - List of subtypes for the relation, as a list of
+       (name, value) tuples
 
-        - entry1       The first Entry object node ID defining the
-                       relation (int)
-        - entry2       The second Entry object node ID defining the
-                       relation (int)
-        - type         The relation type
-        - subtypes     List of subtypes for the relation, as a list of
-                       (name, value) tuples
     """
+
     def __init__(self):
         self._entry1 = None
         self._entry2 = None
