@@ -1,5 +1,5 @@
 # Copyright 2002 by Andrew Dalke.  All rights reserved.
-# Revisions 2007-2009 copyright by Peter Cock.  All rights reserved.
+# Revisions 2007-2016 copyright by Peter Cock.  All rights reserved.
 # Revisions 2008-2009 copyright by Cymon J. Cox.  All rights reserved.
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
@@ -40,9 +40,11 @@ class DBSeq(Seq):
         self.start = start
 
     def __len__(self):
+        """Return the length of the sequence."""
         return self._length
 
     def __getitem__(self, index):  # Seq API requirement
+        """Return a subsequence or single letter."""
         # Note since Python 2.0, __getslice__ is deprecated
         # and __getitem__ is used instead.
         # See http://docs.python.org/ref/sequence-methods.html
@@ -59,7 +61,7 @@ class DBSeq(Seq):
                                                      self.start + i,
                                                      self.start + i + 1)
         if not isinstance(index, slice):
-            raise ValueError("Unexpected index type")
+            raise TypeError("Unexpected index type")
 
         # Return the (sub)sequence as another DBSeq or Seq object
         # (see the Seq obect's __getitem__ method)
@@ -103,10 +105,11 @@ class DBSeq(Seq):
             return Seq(full[::index.step], self.alphabet)
 
     def tostring(self):
-        """Returns the full sequence as a python string (DEPRECATED).
+        """Return the full sequence as a python string (DEPRECATED).
 
         You are now encouraged to use str(my_seq) instead of
-        my_seq.tostring()."""
+        my_seq.tostring().
+        """
         import warnings
         warnings.warn("This method is obsolete; please use str(my_seq) "
                       "instead of my_seq.tostring().",
@@ -116,7 +119,7 @@ class DBSeq(Seq):
                                                  self.start + self._length)
 
     def __str__(self):
-        """Returns the full sequence as a python string."""
+        """Return the full sequence as a python string."""
         return self.adaptor.get_subseq_as_string(self.primary_id,
                                                  self.start,
                                                  self.start + self._length)
@@ -124,15 +127,25 @@ class DBSeq(Seq):
     data = property(tostring, doc="Sequence as string (DEPRECATED)")
 
     def toseq(self):
-        """Returns the full sequence as a Seq object."""
+        """Return the full sequence as a Seq object."""
         # Note - the method name copies that of the MutableSeq object
         return Seq(str(self), self.alphabet)
 
     def __add__(self, other):
+        """Add another sequence or string to this sequence.
+
+        The sequence is first converted to a Seq object before the addition.
+        The returned object is a Seq object, not a DBSeq object
+        """
         # Let the Seq object deal with the alphabet issues etc
         return self.toseq() + other
 
     def __radd__(self, other):
+        """Add another sequence or string to the left.
+
+        The sequence is first converted to a Seq object before the addition.
+        The returned object is a Seq object, not a DBSeq object
+        """
         # Let the Seq object deal with the alphabet issues etc
         return other + self.toseq()
 
@@ -267,12 +280,19 @@ def _retrieve_features(adaptor, primary_id):
             if strand not in (+1, -1, None):
                 raise ValueError("Invalid strand %s found in database for "
                                  "seqfeature_id %s" % (strand, seqfeature_id))
-            if end < start:
+            if start is not None and end is not None and end < start:
                 import warnings
                 from Bio import BiopythonWarning
                 warnings.warn("Inverted location start/end (%i and %i) for "
                               "seqfeature_id %s" % (start, end, seqfeature_id),
                               BiopythonWarning)
+
+            # For SwissProt unknown positions (?)
+            if start is None:
+                start = SeqFeature.UnknownPosition()
+            if end is None:
+                end = SeqFeature.UnknownPosition()
+
             locations.append((location_id, start, end, strand))
         # Get possible remote reference information
         remote_results = adaptor.execute_and_fetchall(
@@ -285,8 +305,8 @@ def _retrieve_features(adaptor, primary_id):
                 v = "%s.%s" % (accession, version)
             else:
                 v = accession
-            # subfeature remote location db_ref are stored as a empty string when
-            # not present
+            # subfeature remote location db_ref are stored as a empty string
+            # when not present
             if dbname == "":
                 dbname = None
             lookup[location_id] = (dbname, v)
@@ -309,39 +329,28 @@ def _retrieve_features(adaptor, primary_id):
             feature.ref_db = dbname
             feature.ref = version
         else:
-            sub_features = feature.sub_features
-            assert sub_features == []
+            locs = []
             for location in locations:
                 location_id, start, end, strand = location
                 dbname, version = lookup.get(location_id, (None, None))
-                subfeature = SeqFeature.SeqFeature()
-                subfeature.type = seqfeature_type
-                subfeature.location = SeqFeature.FeatureLocation(start, end)
-                # subfeature.location_operator = \
-                #    _retrieve_location_qualifier_value(adaptor, location_id)
-                subfeature.strand = strand
-                subfeature.ref_db = dbname
-                subfeature.ref = version
-                sub_features.append(subfeature)
-            # Locations are in order, but because of remote locations for
+                locs.append(SeqFeature.FeatureLocation(start, end,
+                                                       strand=strand,
+                                                       ref=version,
+                                                       ref_db=dbname))
+            # Locations are typically in biological in order (see negative
+            # strands below), but because of remote locations for
             # sub-features they are not necessarily in numerical order:
-            strands = set(sf.strand for sf in sub_features)
+            strands = set(l.strand for l in locs)
             if len(strands) == 1 and -1 in strands:
                 # Evil hack time for backwards compatibility
                 # TODO - Check if BioPerl and (old) Biopython did the same,
                 # we may have an existing incompatibility lurking here...
-                locs = [f.location for f in sub_features[::-1]]
-            else:
-                # All forward, or mixed strands
-                locs = [f.location for f in sub_features]
-            feature.location = SeqFeature.CompoundLocation(
-                locs, seqfeature_type)
-            # TODO - See Bug 2677 - we don't yet record location_operator,
+                locs = locs[::-1]
+            feature.location = SeqFeature.CompoundLocation(locs, "join")
+            # TODO - See Bug 2677 - we don't yet record location operator,
             # so for consistency with older versions of Biopython default
             # to assuming its a join.
-            feature.location_operator = "join"
         seq_feature_list.append(feature)
-
     return seq_feature_list
 
 
@@ -475,11 +484,8 @@ def _retrieve_taxon(adaptor, primary_id, taxon_id):
             # load_ncbi_taxonomy.pl this is how top parent nodes are stored.
             # Personally, I would have used a NULL parent_taxon_id here.
             break
-        if rank != "no rank":
-            # For consistency with older versions of Biopython, we are only
-            # interested in taxonomy entries with a stated rank.
-            # Add this to the start of the lineage list.
-            taxonomy.insert(0, name)
+
+        taxonomy.insert(0, name)
         taxon_id = parent_taxon_id
 
     if taxonomy:
@@ -504,6 +510,15 @@ class DBSeqRecord(SeqRecord):
     """BioSQL equivalent of the Biopython SeqRecord object."""
 
     def __init__(self, adaptor, primary_id):
+        """Create a DBSeqRecord object.
+
+        Arguments:
+         - adaptor - A BioSQL.BioSeqDatabase.Adaptor object
+         - primary_id - An internal integer ID used by BioSQL
+
+        You wouldn't normally create a DBSeqRecord object yourself,
+        this is done for you when using a BioSeqDatabase object
+        """
         self._adaptor = adaptor
         self._primary_id = primary_id
 
